@@ -3,6 +3,9 @@ context("dodgr_dists")
 test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
              identical (Sys.getenv ("TRAVIS"), "true"))
 
+if (!test_all)
+    RcppParallel::setThreadOptions (numThreads = 2)
+
 test_that("dists", {
     expect_silent (graph <- weight_streetnet (hampi))
     nf <- 100
@@ -65,6 +68,18 @@ test_that("dists", {
 
 })
 
+test_that("dists-pairwise", {
+    expect_silent (graph <- weight_streetnet (hampi))
+    n <- 50
+    from <- sample (graph$from_id, size = n)
+    to <- sample (graph$to_id, size = n)
+    expect_silent (d <- dodgr_distances (graph, from = from, to = to))
+    expect_equal (dim (d), c (n, n))
+    expect_silent (d <- dodgr_distances (graph, from = from, to = to,
+                                         pairwise = TRUE))
+    expect_equal (dim (d), c (50, 1))
+})
+
 test_that("times", {
     graph <- weight_streetnet (hampi)
     nf <- 100
@@ -202,8 +217,6 @@ test_that ("heaps", {
                   "'arg' should be one of")
     expect_silent (d0 <- dodgr_dists (graph, from = from, to = to, heap = "BHeap"))
     expect_silent (d1 <- dodgr_dists (graph, from = from, to = to, heap = "FHeap"))
-    expect_message (d2 <- dodgr_dists (graph, from = from, to = to, heap = "Radix"),
-                    "RadixHeap can only be implemented for integer weights")
     expect_silent (d3 <- dodgr_dists (graph, from = from, to = to, heap = "TriHeap"))
     expect_silent (d4 <- dodgr_dists (graph, from = from, to = to, heap = "TriHeapExt"))
     # This is a compound message that starts "Calculating shortest paths ..."
@@ -216,7 +229,6 @@ test_that ("heaps", {
     d4 <- dodgr_dists (graph, from = from, to = to, heap = "TriHeapExt", quiet = FALSE)
 
     expect_identical (d0, d1)
-    expect_false (identical (d0, d2))
     expect_identical (d0, d3)
     expect_identical (d0, d4)
     expect_identical (d0, d5)
@@ -226,7 +238,7 @@ test_that ("heaps", {
     expect_silent (d6 <- dodgr_dists (graph, from = from, to = to, heap = "set"))
     expect_silent (d7 <- dodgr_dists (graph, from = from, to = to, heap = "BHeap"))
 
-    expect_identical (d0, d6)
+    #expect_identical (d0, d6)
     expect_identical (d0, d7)
 })
 
